Page Menu
Home
Phabricator
Search
Configure Global Search
Log In
Files
F15529152
D16885.id40654.diff
No One
Temporary
Actions
View File
Edit File
Delete File
View Transforms
Subscribe
Mute Notifications
Award Token
Flag For Later
Size
2 KB
Referenced Files
None
Subscribers
None
D16885.id40654.diff
View Options
diff --git a/resources/celerity/map.php b/resources/celerity/map.php
--- a/resources/celerity/map.php
+++ b/resources/celerity/map.php
@@ -10,7 +10,7 @@
'conpherence.pkg.css' => '0b64e988',
'conpherence.pkg.js' => '6249a1cf',
'core.pkg.css' => '2f1ecc57',
- 'core.pkg.js' => 'ba34ebda',
+ 'core.pkg.js' => '56f967a5',
'darkconsole.pkg.js' => 'e7393ebb',
'differential.pkg.css' => 'a4ba74b5',
'differential.pkg.js' => '634399e9',
@@ -471,7 +471,7 @@
'rsrc/js/application/uiexample/notification-example.js' => '8ce821c5',
'rsrc/js/core/Busy.js' => '59a7976a',
'rsrc/js/core/DragAndDropFileUpload.js' => '58dea2fa',
- 'rsrc/js/core/DraggableList.js' => '5a13c79f',
+ 'rsrc/js/core/DraggableList.js' => 'bea6e7f4',
'rsrc/js/core/Favicon.js' => '1fe2510c',
'rsrc/js/core/FileUpload.js' => '680ea2c8',
'rsrc/js/core/Hovercard.js' => '1bd28176',
@@ -786,7 +786,7 @@
'phabricator-countdown-css' => '16c52f5c',
'phabricator-dashboard-css' => 'bc6f2127',
'phabricator-drag-and-drop-file-upload' => '58dea2fa',
- 'phabricator-draggable-list' => '5a13c79f',
+ 'phabricator-draggable-list' => 'bea6e7f4',
'phabricator-fatal-config-template-css' => '8f18fa41',
'phabricator-favicon' => '1fe2510c',
'phabricator-feed-css' => 'ecd4ec57',
@@ -1366,14 +1366,6 @@
'javelin-vector',
'javelin-dom',
),
- '5a13c79f' => array(
- 'javelin-install',
- 'javelin-dom',
- 'javelin-stratcom',
- 'javelin-util',
- 'javelin-vector',
- 'javelin-magical-init',
- ),
'5c54cbf3' => array(
'javelin-behavior',
'javelin-stratcom',
@@ -1933,6 +1925,14 @@
'javelin-util',
'javelin-request',
),
+ 'bea6e7f4' => array(
+ 'javelin-install',
+ 'javelin-dom',
+ 'javelin-stratcom',
+ 'javelin-util',
+ 'javelin-vector',
+ 'javelin-magical-init',
+ ),
'bee502c8' => array(
'javelin-behavior',
'javelin-stratcom',
diff --git a/webroot/rsrc/js/core/DraggableList.js b/webroot/rsrc/js/core/DraggableList.js
--- a/webroot/rsrc/js/core/DraggableList.js
+++ b/webroot/rsrc/js/core/DraggableList.js
@@ -297,8 +297,13 @@
if (group[ii].getHasInfiniteHeight()) {
// The math doesn't work out quite right if we actually use
- // Math.Infinity, so approximate infinity as the document height.
- infinity = infinity || JX.Vector.getDocument().y;
+ // Math.Infinity, so approximate infinity as the larger of the
+ // document height or viewport height.
+ if (!infinity) {
+ infinity = Math.max(
+ JX.Vector.getViewport().y,
+ JX.Vector.getDocument().y);
+ }
rp.y = 0;
rd.y = infinity;
File Metadata
Details
Attached
Mime Type
text/plain
Expires
Wed, Apr 23, 5:16 PM (2 d, 2 h ago)
Storage Engine
blob
Storage Format
Encrypted (AES-256-CBC)
Storage Handle
7701872
Default Alt Text
D16885.id40654.diff (2 KB)
Attached To
Mode
D16885: Allow workboard cards to be dragged again by using a larger value for infinity
Attached
Detach File
Event Timeline
Log In to Comment